==> fap-0.9.2.tar.bz2: fap-0.9.2/src/utils/xdg.h <==
/*
 *  Copyright (C) 2011 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef XDG_H
#define XDG_H

#include <fx.h>

/**
 * This is an utility class to deal with standard and user dirs
 * It is based on XDG specs for Linux:
 * http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
 * and CSIDL for Windows:
 * http://msdn.microsoft.com/en-us/library/bb762494(v=vs.85).aspx
 */
class xdg {

private:
#ifdef _WIN32
	static const FXString getWindowsDir(const int nFolder);
#endif
	static const char* parseFile(FXFile& file, char *buffer, FXint& len, FXint& end);

public:
	/// Get the base directory relative to which user specific non-essential
	/// data files should be stored
	static const FXString getCacheDir(void);

	/// Get the base directory relative to which user-specific non-essential
	/// runtime files and other file objects (such as sockets, named pipes,
	/// ...) should be stored
	static const FXString getRuntimeDir(void);

	/// Get the base directory relative to which user specific configuration
	/// files should be stored
	static const FXString getConfigDir(void);

	/// Get the user music directory
	static const FXString getMusicDir(void);

	/// Open a file or URL in the user's preferred application
	static bool open(const FXString& link);
};

#endif

==> fap-0.11.1.tar.bz2: fap-0.11.1/src/utils/xdg.h <==
/*
 *  Copyright (C) 2011-2015 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef XDG_H
#define XDG_H

#include <fx.h>

/**
 * This is an utility class to deal with standard and user dirs
 * It is based on XDG specs for Linux:
 * http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
 * and CSIDL for Windows:
 * http://msdn.microsoft.com/en-us/library/bb762494(v=vs.85).aspx
 */
namespace xdg {
	/// Get the base directory relative to which user specific non-essential
	/// data files should be stored
	const FXString getCacheDir(void);

	/// Get the base directory relative to which user-specific non-essential
	/// runtime files and other file objects (such as sockets, named pipes,
	/// ...) should be stored
	const FXString getRuntimeDir(void);

	/// Get the base directory relative to which user specific configuration
	/// files should be stored
	const FXString getConfigDir(void);

	/// Get the user music directory
	const FXString getMusicDir(void);

	/// Open a file or URL in the user's preferred application
	bool open(const FXString& link);
}

#endif
